@@ -5,5 +5,5 @@ Created on Sun Jan 17 14:14:46 2021
 @author: Ali Jazayeri
 """
 
-import tempowork.tw as tw
+from tempowork import tw as tw
  
\ No newline at end of file
